
#ifndef _C14_re673_
#define _C14_re673_

#ifdef __cplusplus
extern "C" {
#endif

extern void F1258_12018(EIF_REFERENCE, EIF_REFERENCE);
extern void F1258_12019(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit673(void);

#ifdef __cplusplus
}
#endif

#endif
